Name:           veusz
Version:        1.18
Release:        %mkrel 10
Summary:        GUI scientific plotting package

Group:          Sciences/Mathematics
# The entire source code is GPLv2+ except helpers/src/_nc_cntr.c which is Python
License:        GPLv2+ and Python
URL:            http://home.gna.org/veusz/
Source0:        http://download.gna.org/veusz/veusz-%{version}.tar.gz
Source1:        %{name}.desktop
Source2:        %{name}.xml
Patch0:         veusz-astropy.patch

BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-numpy-devel
BuildRequires:  python-qt4 
BuildRequires:  qt4-devel 
BuildRequires:  sip-devel

BuildRequires: x11-server-xvfb 
BuildRequires: xauth

Requires:       python-astropy >= 0.2.3
Requires:       python-sampy

%{?_sip_api:Requires: sip-api(%{_sip_api_major}) >= %{_sip_api}}
Requires:       python-numpy python-qt4 /usr/bin/env
Provides:       python-veusz = %{version}

# we don't want to provide private python extension libs
%{?filter_setup:
%filter_provides_in %{python_sitearch}/veusz/helpers/.*\.so$
%filter_setup
}

%description
Veusz is a scientific plotting package, designed to create
publication-ready Postscript/PDF/SVG output. It features GUI,
command-line, and scripting interfaces. Graphs are constructed from
widgets, allowing complex layouts to be designed. Veusz supports
plotting functions, data with error bars, keys, labels, stacked plots,
ternary plots, vector plots, contours, images, shapes and fitting
data.

%prep
%setup -q -n veusz-%{version}
%apply_patches 
find -name \*~ | xargs rm -f

# change path of where to look for COPYING - should be docdir
sed -i "/COPYING/s@=.*@=open('%{vdoc}/COPYING', 'rU')@"  \
    dialogs/aboutdialog.py

# remove shebangs from scripts which aren't installed
# (veusz allows these to be executed if app isn't installed properly)
sed -i '/^#!/d' veusz_main.py
sed -i '/^#!/d' veusz_listen.py

%build
CFLAGS="$RPM_OPT_FLAGS" %{__python} setup.py build

%install
# veusz-resource-dir: put data files in location given
%{__python} setup.py install --skip-build --root %{buildroot} \
    --veusz-resource-dir=%{buildroot}/%{_datadir}/veusz \
    --disable-install-examples

# tell veusz where its resource directory is in _datadir
ln -s %{_datadir}/veusz \
    %{buildroot}%{python_sitearch}/veusz/resources

# tell it where to look for examples
ln -s %{_defaultdocdir}/%{name}-%{version}/examples \
    %{buildroot}%{_datadir}/veusz

# install desktop file
desktop-file-install  \
    --dir %{buildroot}%{_datadir}/applications \
    %{SOURCE1}

# file to register .vsz mimetype
mkdir -p %{buildroot}%{_datadir}/mime/packages/
cp %{SOURCE2} %{buildroot}%{_datadir}/mime/packages/

# symlink main veusz icon into pixmaps (for desktop file)
mkdir %{buildroot}%{_datadir}/pixmaps
ln -s ../veusz/windows/icons/veusz_48.png \
    %{buildroot}%{_datadir}/pixmaps/veusz.png

# also link in hicolor icons
for size in 16 32 48 64 128; do
    odir=%{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps
    mkdir -p $odir
    ln -s %{_datadir}/veusz/windows/icons/veusz_${size}.png ${odir}/veusz.png
done
odir=%{buildroot}%{_datadir}/icons/hicolor/scalable/apps
mkdir -p $odir
ln -s %{_datadir}/veusz/windows/icons/veusz.svg $odir

# install man pages
mkdir -p %{buildroot}%{_mandir}/man1
install -p Documents/veusz.1 Documents/veusz_listen.1 -m 0644 \
    %{buildroot}%{_mandir}/man1

%check
# self test has to run in X environment
# as the data directory hasn't got the same absolute path we have
# to define VEUSZ_RESOURCE_DIR
PYTHONPATH=%{buildroot}%{python_sitearch} \
    VEUSZ_RESOURCE_DIR=%{buildroot}%{_datadir}/veusz \
    xvfb-run \
    --auto-servernum \
    --server-args "-screen 0 640x480x24" \
    python tests/runselftest.py

%files
%doc README AUTHORS COPYING
%doc examples
%doc Documents/manual.html
%doc Documents/manimages
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/applications/*
%{_datadir}/mime/packages/*
%{_datadir}/pixmaps/*
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/veusz
%{python_sitearch}/veusz-*.egg-info
%{python_sitearch}/veusz


%changelog
* Sat Nov 22 2014 alexl <alexl> 1.18-10.mga5
+ Revision: 798338
- translated desktop file (merged with OpenSuse and Debian)

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.18-8.mga5
+ Revision: 730702
- rebuild for missing pythoneggs deps

* Fri Sep 26 2014 tv <tv> 1.18-7.mga5
+ Revision: 725276
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1.18-6.mga5
+ Revision: 690199
- Mageia 5 Mass Rebuild

  + pterjan <pterjan>
    - Rebuild for new Python

* Wed Mar 19 2014 fwang <fwang> 1.18-4.mga5
+ Revision: 605485
- rebuild for new sip

* Tue Oct 22 2013 umeabot <umeabot> 1.18-3.mga4
+ Revision: 544609
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.18-2.mga4
+ Revision: 499970
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 04 2013 joequant <joequant> 1.18-1.mga4
+ Revision: 463103
- update to 1.18

* Tue Jun 18 2013 joequant <joequant> 1.17.1-1.mga4
+ Revision: 444683
- fix typo
- imported package veusz

